.. lstail documentation master file

Lstail
======

A command line tool to query log events from ElasticSearch,
a bit like tail for Logstash/ElasticSearch.


Contents
--------

.. toctree::
   :maxdepth: 2

   about.rst
   installation.rst
   config.rst
   usage.rst
